@@ -17,6 +17,11 @@
               msg = "Have not implemented screen printing with kableExtra yet. Try set_opts(output = 'huxtable')")
   assert_that(dest %in% c("html", "latex"))
 
+  ##
+  ## Functions below might use as.data.frame() if the argument is not a data.frame,
+  ## which creates unique column names, which is not what we want.
+  class(df1) = "data.frame"
+
   ##
   if (dest == "html") {
     hh = df1 %>% kableExtra::kbl(format = "html"
